<?php
if( !class_exists('TRP_String_Translation_API_WooCommerce_Slug') ) {
    class TRP_String_Translation_API_WooCommerce_Slug
    {
        protected $config;
        protected $helper;
        protected $option_based_strings;
        protected $settings;
        protected $slug_query;
        protected $editor_actions;

        public function __construct($settings)
        {
            $this->settings = $settings;
            $this->helper = new TRP_String_Translation_Helper();
            $this->slug_query = new TRP_Slug_Query();
            $this->editor_actions = new TRP_IN_SP_Editor_Actions( $this->slug_query, $settings );
        }

        public function get_strings()
        {
            $this->helper->check_ajax('woocommerce-slug', 'get');

            $woo_cpt_slugs = array();
            $woo_tax_slugs = array();
            $array_of_tax_woo_slugs = array( 'category_base', 'tag_base' );
            $dictionary_by_original_cpt = [];
            $dictionary_by_original_tax = [];

            $woocommerce_permalink_options = get_option( 'woocommerce_permalinks', false);
            $woo_first_cpt_slugs = $woocommerce_permalink_options[ 'product_base' ];

            if ( $woo_first_cpt_slugs == 'product' || $woo_first_cpt_slugs == '/shop' || $woo_first_cpt_slugs == '/shop/%product_cat%' ) {
                if ( $this->settings['default-language'] != 'en_US') {
                    $woo_cpt_slugs[] = get_option( "trp_woo_english_slug_map_product_{$this->settings['default-language']}" );

                }else{
                    $woo_cpt_slugs[] = 'product';
                }
            }else{
                $woo_custom_permalink = explode( "/", $woo_first_cpt_slugs );
                foreach ( $woo_custom_permalink as $woo_custom_slug ){
                    if ( !empty($woo_custom_slug) && strpos( $woo_custom_slug, '%') === false ){
                        $woo_cpt_slugs[] = $woo_custom_slug;
                    }
                }
            }

            $is_the_cpt_slug_in_original_slug_db = $this->slug_query->get_ids_from_original( $woo_cpt_slugs );
            if ( empty( $is_the_cpt_slug_in_original_slug_db ) ) {
                $this->slug_query->insert_original_slugs( array( 'original' => $woo_cpt_slugs, 'type' => 'post-type-base' ) );
                $translated_woo_cpt_slugs = [];
            } else {
                $translated_woo_cpt_slugs = $this->slug_query->get_translated_slugs_from_original( $woo_cpt_slugs );
            }

            $translationsArrays_woo_cpt = new TRP_String_Translation_Array( $woo_cpt_slugs, $translated_woo_cpt_slugs, 'post-type-base' );
            $formatted_array_woo_cpt = $translationsArrays_woo_cpt->get_formatted_translations_array();

            $translationsArrays_woo_cpt = $formatted_array_woo_cpt;


            if ( $this->settings['default-language'] == 'en_US') {
                foreach ( $array_of_tax_woo_slugs as $woo_slugs ) {
                    $woo_tax_slugs[] = $woocommerce_permalink_options[ $woo_slugs ];

                    $is_the_tax_slug_in_original_slug_db = $this->slug_query->get_ids_from_original( $woo_tax_slugs );
                    if ( empty( $is_the_tax_slug_in_original_slug_db ) ) {
                        $this->slug_query->insert_original_slugs( array( 'original' => $woo_tax_slugs, 'type' => 'taxonomy' ) );
                    }
                }
            }else{
                $woo_tax_slugs_english_cat = get_option( "trp_woo_english_slug_map_product_category_{$this->settings['default-language']}" );
                $woo_tax_slugs_english_tag = get_option( "trp_woo_english_slug_map_product_tag_{$this->settings['default-language']}" );
                $woo_tax_slugs = array( $woo_tax_slugs_english_cat, $woo_tax_slugs_english_tag );

            }

            $translated_woo_tax_slugs = $this->slug_query->get_translated_slugs_from_original( $woo_tax_slugs );

            $translationsArrays_woo_tax = new TRP_String_Translation_Array( $woo_tax_slugs, $translated_woo_tax_slugs, 'taxonomy' );
            $formatted_array_wpp_tax = $translationsArrays_woo_tax->get_formatted_translations_array();
            $translationsArrays_woo_tax = $formatted_array_wpp_tax;

            if ( $woo_cpt_slugs  && count( $woo_cpt_slugs ) > 0 ) {

                foreach ( $woo_cpt_slugs as $slug ) {
                    $dictionary_by_original_cpt[] = array(
                        'original'          => $slug,
                        'type'              => 'post-type-base',
                        'translationsArray' => $translationsArrays_woo_cpt[$slug]
                    );
                }
            }

            if ( $woo_tax_slugs && count( $woo_tax_slugs ) > 0 ) {

                foreach ( $woo_tax_slugs as $slug ) {
                    $dictionary_by_original_tax[] = array(
                        'original' => $slug,
                        'type' => 'taxonomy',
                        'translationsArray' => $translationsArrays_woo_tax[$slug]
                    );
                }
            }
            $return = array(
                'dictionary' => array_merge( $dictionary_by_original_cpt, $dictionary_by_original_tax ),
                'totalItems' => count( $woo_cpt_slugs ) + count( $woo_tax_slugs )
            );

            echo trp_safe_json_encode($return);//phpcs:ignore
            wp_die();
        }

        // saving will go through cpt and taxonomies save functions
        public function save_strings()
        {

        }
    }
}
