<?php

/**
 * The code that runs during plugin activation.
 */


if(!function_exists('trp_in_sp_activator')){
    function trp_in_sp_activator( $addon ){
        if ( $addon === 'tp-add-on-seo-pack/tp-seo-pack.php' ) {
            trp_in_sp_wpseo_clear_sitemap();
            trp_in_sp_create_db_tables();
        }
    }

    add_action('trp_add_ons_activate', 'trp_in_sp_activator', 10, 1);
    add_action('trp_add_ons_deactivate','trp_in_sp_activator', 10, 1);
}

if(!function_exists('trp_in_sp_wpseo_clear_sitemap')) {
    function trp_in_sp_wpseo_clear_sitemap() {
        global $wpdb;
        // delete all "yst_sm" transients
        $sql = "
            DELETE
            FROM {$wpdb->options}
            WHERE option_name like '\_transient\_yst\_sm%'
            OR option_name like '\_transient\_timeout\_yst\_sm%'
        ";

        $wpdb->query( $sql );
    }
}

function trp_in_sp_create_db_tables(){
    require_once ABSPATH . 'wp-admin/includes/upgrade.php';

    global $wpdb;

    $original_table_name    = $wpdb->prefix . 'trp_slug_original';
    $translation_table_name = $wpdb->prefix . 'trp_slug_translation';

    $original_table_exists    = $wpdb->get_var("SHOW TABLES LIKE '$original_table_name'") == $original_table_name;
    $translation_table_exists = $wpdb->get_var("SHOW TABLES LIKE '$translation_table_name'") == $translation_table_name;

    $collation = 'utf8mb4_general_ci';

    if ( !$original_table_exists ) {
        $sql_original = "CREATE TABLE $original_table_name (
            id INT NOT NULL AUTO_INCREMENT,
            original VARCHAR(255) NOT NULL UNIQUE,
            type VARCHAR(50),
            PRIMARY KEY (id),
            INDEX idx_original (original)
        ) COLLATE $collation";

        dbDelta( $sql_original );
    }

    if ( !$translation_table_exists ) {
        $sql_translation = "CREATE TABLE $translation_table_name (
            id INT NOT NULL AUTO_INCREMENT,
            original_id INT NOT NULL,
            translated VARCHAR(255) NOT NULL,
            language VARCHAR(20),
            status INT,
            PRIMARY KEY (id),
            UNIQUE INDEX idx_original_id_language (original_id, language),
            INDEX idx_language (language),
            INDEX idx_translated (translated),
            FOREIGN KEY (original_id) REFERENCES $original_table_name(id) ON DELETE CASCADE
        ) COLLATE $collation";

        dbDelta( $sql_translation );
    }
}